<?xml version="1.0" encoding="UTF-8"?>
<!-- Auf GeoInfoDok 6.0 -->
<xsl:stylesheet version="1.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:date="http://www.jclark.com/xt/java/java.util.Date"
		xmlns:xsd="http://www.w3.org/2001/XMLSchema"
		xmlns:xlink="http://www.w3.org/1999/xlink"
		xmlns:adv="http://www.adv-online.de/namespaces/adv/gid/6.0"
		xmlns:ext="http://www.jclark.com/xt/java/de.adv-online.AAA"
		xmlns:ogc="http://www.adv-online.de/namespaces/adv/gid/ogc"
		xmlns:gml="http://www.opengis.net/gml/3.2">
	<xsl:output method="xml" encoding="UTF-8" indent="yes"/>
	<xsl:include href="../utility.xslt"/>
	<!-- =========================================================== -->
	<!-- Gebiet -->
	<xsl:variable name="gemeinde">
		<xsl:copy-of select="document('E1.xml')//AX_KommunalesGebiet"/>
	</xsl:variable>
	<!-- Korrekturfaktor -->
	<xsl:variable name="korrekturfaktor">
		<xsl:choose>
			<xsl:when test="function-available('ext:berechneFlaeche')">
				<xsl:value-of select="$gemeinde/adv:amtlicheGemeindeflaeche div ext:berechneFlaeche($gemeinde/adv:position)"/>
			</xsl:when>
			<xsl:otherwise>1.0</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<!-- Gesamtflaeche -->
	<!-- =========================================================== -->
	<xsl:template name="flaechensummeOAGD">
		<xsl:param name="tn"/>
		<xsl:param name="fkt"/>
		<!-- nur wenn Teilflächen vorhanden -->
		<xsl:if test="count($tn)>0">
			<flaechensummeOAGD>
				<AX_K_TNFL>
					<!-- sinnvoller wäre eine Entschluesselung für die Ausgabe -->
					<funktionOA><xsl:value-of select="$fkt"/></funktionOA>
					<xsl:variable name="flaeche">
						<xsl:call-template name="summiereTeilflaechen">
							<xsl:with-param name="tn" select="$tn"/>
							<xsl:with-param name="flurstuecksflaeche" select="$gebiet/adv:position"/>
							<xsl:with-param name="korrekturfaktor" select="$korrekturfaktor"/>
						</xsl:call-template>
					</xsl:variable>
					<flaeche>
						<xsl:value-of select="$flaeche"/>
					</flaeche>
				</AX_K_TNFL>
			</flaechensummeOAGD>
		</xsl:if>
	</xsl:template>
	<!-- =========================================================== -->
	<xsl:template name="flaechensummeHGrGD">
		<xsl:param name="tn"/>
		<xsl:param name="fkt"/>
		<!-- nur wenn Teilflächen vorhanden -->
		<xsl:if test="count($tn)>0">
			<flaechensummeHGrGD>
				<AX_K_TNHGR>
					<!-- Falls per Revision bei AX_K_TNHGR/funktionHGr der Typ der bisherigen Codelist nun Enumeration ist, dann hier entschluesselte Werte für die Ausgabe -->
					<funktionHGr><xsl:value-of select="$fkt"/></funktionHGr>
					<flaeche>
						<xsl:call-template name="summiereTeilflaechen">
							<xsl:with-param name="tn" select="$tn"/>
							<xsl:with-param name="flurstuecksflaeche" select="$gemeinde/adv:position"/>
							<xsl:with-param name="korrekturfaktor" select="$korrekturfaktor"/>
						</xsl:call-template>
					</flaeche>
				</AX_K_TNHGR>
			</flaechensummeHGrGD>
		</xsl:if>
	</xsl:template>					
	<!-- =========================================================== -->
	<xsl:template match="/">
		<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->
		<AX_StatistikDerFlaechenDerTatsaechlichenNutzung xmlns="http://www.adv-online.de/namespaces/adv/gid/6.0" xmlns:adv="http://www.adv-online.de/namespaces/adv/gid/6.0" xmlns:gml="http://www.opengis.net/gml/3.2" xmlns:ogc="http://www.adv-online.de/namespaces/adv/gid/ogc" xmlns:wfs="http://www.adv-online.de/namespaces/adv/gid/wfs" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:ext="http://www.jclark.com/xt/java/de.adv-online.AAA" xsi:schemaLocation="http://www.adv-online.de/namespaces/adv/gid/6.0 NAS-Operationen.xsd">
			<erfolgreich>true</erfolgreich>
			<antragsnummer>
				<xsl:value-of select="//adv:antragsnummer"/>
			</antragsnummer>
			<allgemeineAngaben>
				<AX_K_Benutzungsergebnis>
					<folgeverarbeitung>
						<AX_FOLGEVA>
							<datenformat>1000</datenformat>
						</AX_FOLGEVA>
					</folgeverarbeitung>
					<xsl:apply-templates select="//adv:empfaenger" mode="copy-it"/>
				</AX_K_Benutzungsergebnis>
			</allgemeineAngaben>
			<ausgabekopf>
				<xsl:apply-templates select="document('AX_K_AUSGKOPF_Standard.xml')//adv:AX_K_AUSGKOPF_Standard" mode="copy-it"/>
			</ausgabekopf>
			<gebiet>
				<xsl:variable name="gkz" select="document('E1.xml')//AX_KommunalesGebiet/adv:gemeindekennzeichen/adv:AX_Gemeindekennzeichen"/>
				<xsl:value-of select="document('E1.xml')//adv:AX_Gemeinde[adv:schluesselGesamt=concat($gkz/adv:land,$gkz/adv:regierungsbezirk,$gkz/adv:kreis,$gkz/adv:gemeinde)]/adv:bezeichnung"/>
			</gebiet>
			<!-- flaechensummeOAGD -->
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4101"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Wohnbaufläche" statt "4101" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Wohnbauflaeche"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4102"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Industrie- und Gewerbefläche" statt "4102" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_IndustrieUndGewerbeflaeche"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="1400"/> <!-- Handel und Dienstleistungen --><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Handel und Dienstleistungen" statt "1400" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_IndustrieUndGewerbeflaeche[substring(adv:funktion,1,2)='14']"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="1700"/> <!-- Industrie und Gewerbe --><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Industrie und Gewerbe" statt "1700" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_IndustrieUndGewerbeflaeche[substring(adv:funktion,1,2)='17']"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="2500"/> <!-- Versorgungsanlage --><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Versorgungsanlage" statt "2500" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_IndustrieUndGewerbeflaeche[substring(adv:funktion,1,2)='25']"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="2600"/> <!-- Entsorgung --><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Entsorgung" statt "2600" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_IndustrieUndGewerbeflaeche[substring(adv:funktion,1,2)='26']"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4103"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Halde" statt "4103" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Halde"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4104"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Bergbaubetrieb" statt "4104" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Bergbaubetrieb"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4105"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Tagebau, Grube, Steinbruch" statt "4105" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_TagebauGrubeSteinbruch"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4106"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Fläche gemischter Nutzung" statt "4106" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_FlaecheGemischterNutzung"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4107"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Fläche besonderer funktionaler Prägung" statt "4107" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_FlaecheBesondererFunktionalerPraegung"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4108"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Sport-, Freizeit und Erholungsfläche" statt "4108" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_SportFreizeitUndErholungsflaeche"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4400"/> <!-- Grünanlage --><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Grünanlage" statt "4400" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_SportFreizeitUndErholungsflaeche[substring(adv:funktion,1,2)='44']"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4109"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Friedhof" statt "4109" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Friedhof"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4201"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Straßenverkehr" statt "4201" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Strassenverkehr"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4206"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Weg" statt "4206" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Weg"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4209"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Platz" statt "4209" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Platz"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4210"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Bahnverkehr" statt "4210" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Bahnverkehr"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4215"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Flugverkehr" statt "4215" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Flugverkehr"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4216"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Schiffsverkehr" statt "4216" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Schiffsverkehr"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4301"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Landwirtschaft" statt "4301" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Landwirtschaft"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4302"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Wald" statt "4302" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Wald"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4303"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Gehölz" statt "4303" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Gehoelz"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4304"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Heide" statt "4304" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Heide"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4305"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Moor" statt "4305" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Moor"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4306"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Sumpf" statt "4306" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Sumpf"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4307"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "UnlandVegetationslose Fläche" statt "4307" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_UnlandVegetationsloseFlaeche"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4401"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Fließgewässer" statt "4401" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Fliessgewaesser"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4405"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Hafenbecken" statt "4405" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Hafenbecken"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4406"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Stehendes Gewässer" statt "4406" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_StehendesGewaesser"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeOAGD">
				<xsl:with-param name="fkt" select="4407"/><!-- Falls per Revision bei AX_K_TNFL/funktionOA bei der bisherigen Codelist nun der Datentyp Enumeration gesetzt wurde, dann wird hier entschluesselte Wert "Meer" statt "4407" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Meer"/>
			</xsl:call-template >
			<!-- flaechensummeHGrGD: nicht optimal, da einzelnene Summen schon berechnet worden sind -->
			<xsl:call-template name="flaechensummeHGrGD">
				<xsl:with-param name="fkt" select="4100"/><!-- Falls per Revision bei AX_K_TNHGR/funktionHGr der Typ der bisherigen Codelist nun Enumeration ist, dann wird hier entschluesselte Wert "Siedlung" statt "4100" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Wohnbauflaeche|
												   document('E2.xml')/AX_IndustrieUndGewerbeflaeche|
												   document('E2.xml')/AX_Halde|
												   document('E2.xml')/AX_Bergbaubetrieb|
												   document('E2.xml')/AX_TagebauGrubeSteinbruch|
												   document('E2.xml')/AX_FlaecheGemischterNutzung|
												   document('E2.xml')/AX_FlaecheBesondererFunktionalerPraegung|
												   document('E2.xml')/AX_SportFreizeitUndErholungsflaeche|
												   document('E2.xml')/AX_Friedhof"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeHGrGD">
				<xsl:with-param name="fkt" select="4200"/><!-- Falls per Revision bei AX_K_TNHGR/funktionHGr der Typ der bisherigen Codelist nun Enumeration ist, dann wird hier entschluesselte Wert "Verkehr" statt "4200" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Strassenverkehr|
												   document('E2.xml')/AX_Weg|
												   document('E2.xml')/AX_Platz|
												   document('E2.xml')/AX_Bahnverkehr|
												   document('E2.xml')/AX_Flugverkehr|
												   document('E2.xml')/AX_Schiffsverkehr"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeHGrGD">
				<xsl:with-param name="fkt" select="4300"/><!-- Falls per Revision bei AX_K_TNHGR/funktionHGr der Typ der bisherigen Codelist nun Enumeration ist, dann wird hier entschluesselte Wert "Vegetation" statt "4300" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Landwirtschaft|
												   document('E2.xml')/AX_Wald|
												   document('E2.xml')/AX_Gehoelz|
												   document('E2.xml')/AX_Heide|
												   document('E2.xml')/AX_Moor|
												   document('E2.xml')/AX_Sumpf|
												   document('E2.xml')/AX_UnlandVegetationsloseFlaeche"/>
			</xsl:call-template >
			<xsl:call-template name="flaechensummeHGrGD">
				<xsl:with-param name="fkt" select="4400"/><!-- Falls per Revision bei AX_K_TNHGR/funktionHGr der Typ der bisherigen Codelist nun Enumeration ist, dann wird hier entschluesselte Wert "Gewässer" statt "4400" übergeben. -->
				<xsl:with-param name="tn"  select="document('E2.xml')/AX_Fliessgewaesser|
												   document('E2.xml')/AX_Hafenbecken|
												   document('E2.xml')/AX_StehendesGewaesser|
												   document('E2.xml')/AX_Meer"/>
			</xsl:call-template >
			<!-- gesamtflaecheGD -->
			<gesamtflaecheGD>
				<xsl:value-of select="$gemeinde/adv:amtlicheGemeindeflaeche"/>
			</gesamtflaecheGD>
		</AX_StatistikDerFlaechenDerTatsaechlichenNutzung>
	</xsl:template>
	<!-- =========================================================== -->
</xsl:stylesheet>
